@@ -1,8 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::Cell;
-BEGIN {
-  $Spreadsheet::XLSX::Reader::LibXML::Cell::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv('v0.36.18');
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = qv('v0.36.24');
 
 $| = 1;
 use 5.010;
