@@ -1,8 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::Error;
-BEGIN {
-  $Spreadsheet::XLSX::Reader::LibXML::Error::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv('v0.36.18');
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = qv('v0.36.24');
 
 use Moose;
 use Carp qw( cluck );
