@@ -1,8 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::GetCell;
-BEGIN {
-  $Spreadsheet::XLSX::Reader::LibXML::GetCell::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv('v0.36.18');
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = qv('v0.36.24');
 
 use	Moose::Role;
 requires qw(
