@@ -1,8 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings;
-BEGIN {
-  $Spreadsheet::XLSX::Reader::LibXML::XMLReader::SharedStrings::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv('v0.36.18');
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = qv('v0.36.24');
 
 use 5.010;
 use Moose;
@@ -59,8 +57,16 @@ sub get_shared_string_position{
 	if( !$self->has_position ){
 		###LogSD	$phone->talk( level => 'debug', message => [
 		###LogSD		"Pulling the first cell" ] );
-		my $found_it = $self->next_element( 'si' );
-		if( $found_it < 1 ){
+		my $found_it;
+		eval '$found_it = $self->next_element( "si" )';
+		if( $@ ){
+			###LogSD	$phone->talk( level => 'debug', message => [
+			###LogSD		"Found an unexpected end of file: ", $@] );
+			$self->set_error( 'libxml2 error message' . $@ );
+			$self->_set_unique_count( 0 );
+			$self->_i_am_here( 0 );
+			return undef;
+		}elsif( defined $found_it and $found_it < 1 ){
 			$self->set_error( "No strings stored in the sharedStrings file" );
 			return undef;
 		}
@@ -71,7 +77,23 @@ sub get_shared_string_position{
 	while( $self->where_am_i < $position ){
 		###LogSD	$phone->talk( level => 'debug', message => [
 		###LogSD		"Pulling the next cell: " . ($self->where_am_i + 1) ] );
-		$self->next_element( 'si' );
+		my $found_it;
+		eval '$found_it = $self->next_element( "si" )';
+		if( $@ ){
+			###LogSD	$phone->talk( level => 'debug', message => [
+			###LogSD		"Found an unexpected end of file: ", $@] );
+			$self->set_error( 'libxml2 error message' . $@ );
+			$self->_set_unique_count( $self->where_am_i + 1 );
+			$self->_i_am_here( 0 );
+			return undef;
+		}elsif( defined $found_it and $found_it < 1 ){
+			###LogSD	$phone->talk( level => 'debug', message => [
+			###LogSD		"Found an unexpected end of file: $found_it" ] );
+			$self->set_error( "Unexpected end of file found" );
+			$self->_set_unique_count( $self->where_am_i + 1 );
+			$self->_i_am_here( 0 );
+			return undef;
+		}
 		$self->_i_am_here( $self->where_am_i + 1 );
 	}
 	
@@ -82,6 +104,8 @@ sub get_shared_string_position{
 	###LogSD	$phone->talk( level => 'trace',  message =>[
 	###LogSD		"Element parse resulted in:", $init_ref ] );
 	if( is_HashRef( $init_ref ) ){
+		###LogSD	$phone->talk( level => 'trace',  message =>[
+		###LogSD		"This is a hash ref" ] );
 		if( exists $init_ref->{list} ){
 			my ( $raw_text, $rich_text );
 			for my $element( @{$init_ref->{list}} ){
@@ -94,7 +118,7 @@ sub get_shared_string_position{
 			$init_ref = $init_ref->{t};
 		}
 	}else{
-		set_error( "Unable to parse the shared string position: $position" );
+		$self->set_error( "Unable to parse the shared string position: $position" );
 		return undef;
 	}
 	$self->_set_last_position_ref( $init_ref );
