@@ -1,8 +1,6 @@
 package Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles;
-BEGIN {
-  $Spreadsheet::XLSX::Reader::LibXML::XMLReader::Styles::AUTHORITY = 'cpan:JANDREW';
-}
-use version; our $VERSION = qv('v0.36.18');
+our $AUTHORITY = 'cpan:JANDREW';
+use version; our $VERSION = qv('v0.36.24');
 
 use 5.010;
 use Moose;
